@@ -50,7 +50,7 @@ pub trait SerdeEncryptPublicKey {
     where
         Self: Serialize,
     {
-        let serialized = Self::S::serialize(&self)?;
+        let serialized = Self::S::serialize(self)?;
         let plain_msg = PlainMessagePublicKey::new(serialized.into_vec());
         plain_msg.encrypt(combined_key)
     }
