@@ -56,7 +56,7 @@ pub trait SerdeEncryptSharedKey {
     where
         Self: Serialize,
     {
-        let serialized = Self::S::serialize(&self)?;
+        let serialized = Self::S::serialize(self)?;
         let plain_msg = PlainMessageSharedKey::new(serialized.into_vec());
         plain_msg.encrypt(shared_key)
     }
