@@ -8,7 +8,7 @@
 mod test_util;
 
 use serde::{Deserialize, Serialize};
-use serde_encrypt::serialize::impls::CborSerializer;
+use serde_encrypt::serialize::impls::BincodeSerializer;
 use serde_encrypt::shared_key::SharedKey;
 use serde_encrypt::traits::{SerdeEncryptPublicKey, SerdeEncryptSharedKey};
 use serde_encrypt::AsSharedKey;
@@ -24,7 +24,7 @@ fn test_serde_encrypt_public_key_large_message() {
     combined_keys_gen!(sender_combined_key, receiver_combined_key);
 
     impl SerdeEncryptPublicKey for Message {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Message(vec![42u8; SIZE]);
@@ -36,7 +36,7 @@ fn test_serde_encrypt_shared_key_large_message() {
     let shared_key = SharedKey::generate();
 
     impl SerdeEncryptSharedKey for Message {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Message(vec![42u8; SIZE]);
